TokioRuntimeMetrics

Struct TokioRuntimeMetrics 

pub struct TokioRuntimeMetrics {
Show 43 fields pub workers_count: usize, pub total_park_count: u64, pub max_park_count: u64, pub min_park_count: u64, pub total_busy_duration: Duration, pub max_busy_duration: Duration, pub min_busy_duration: Duration, pub global_queue_depth: usize, pub elapsed: Duration, pub mean_poll_duration: Duration, pub mean_poll_duration_worker_min: Duration, pub mean_poll_duration_worker_max: Duration, pub poll_time_histogram: Vec<u64>, pub total_noop_count: u64, pub max_noop_count: u64, pub min_noop_count: u64, pub total_steal_count: u64, pub max_steal_count: u64, pub min_steal_count: u64, pub total_steal_operations: u64, pub max_steal_operations: u64, pub min_steal_operations: u64, pub num_remote_schedules: u64, pub total_local_schedule_count: u64, pub max_local_schedule_count: u64, pub min_local_schedule_count: u64, pub total_overflow_count: u64, pub max_overflow_count: u64, pub min_overflow_count: u64, pub total_polls_count: u64, pub max_polls_count: u64, pub min_polls_count: u64, pub total_local_queue_depth: usize, pub max_local_queue_depth: usize, pub min_local_queue_depth: usize, pub blocking_queue_depth: usize, pub live_tasks_count: usize, pub blocking_threads_count: usize, pub idle_blocking_threads_count: usize, pub budget_forced_yield_count: u64, pub io_driver_ready_count: u64, pub mean_polls_per_park: f64, pub busy_ratio: f64,
}
Метрики tokio

Fields

workers_count: usize

The number of worker threads used by the runtime.

Ссылка: [tokio_metrics::RuntimeMetrics::workers_count]

total_park_count: u64

The number of times worker threads parked.

Ссылка: [tokio_metrics::RuntimeMetrics::total_park_count]

max_park_count: u64

The maximum number of times any worker thread parked.

Ссылка: [tokio_metrics::RuntimeMetrics::max_park_count]

min_park_count: u64

The minimum number of times any worker thread parked.

Ссылка: [tokio_metrics::RuntimeMetrics::min_park_count]

total_busy_duration: Duration

The amount of time worker threads were busy.

Ссылка: [tokio_metrics::RuntimeMetrics::total_busy_duration]

max_busy_duration: Duration

The maximum amount of time a worker thread was busy.

Ссылка: [tokio_metrics::RuntimeMetrics::max_busy_duration]

min_busy_duration: Duration

The minimum amount of time a worker thread was busy.

Ссылка: [tokio_metrics::RuntimeMetrics::min_busy_duration]

global_queue_depth: usize

The number of tasks currently scheduled in the runtime’s global queue.

Ссылка: [tokio_metrics::RuntimeMetrics::global_queue_depth]

elapsed: Duration

Total amount of time elapsed since observing runtime metrics.

Ссылка: [tokio_metrics::RuntimeMetrics::elapsed]

mean_poll_duration: Duration

The average duration of a single invocation of poll on a task.

Ссылка: [tokio_metrics::RuntimeMetrics::mean_poll_duration]

mean_poll_duration_worker_min: Duration

The average duration of a single invocation of poll on a task on the worker with the lowest value.

Ссылка: [tokio_metrics::RuntimeMetrics::mean_poll_duration_worker_min]

mean_poll_duration_worker_max: Duration

The average duration of a single invocation of poll on a task on the worker with the highest value.

Ссылка: [tokio_metrics::RuntimeMetrics::mean_poll_duration_worker_max]

poll_time_histogram: Vec<u64>

A histogram of task polls since the previous probe grouped by poll times.

total_noop_count: u64

The number of times worker threads unparked but performed no work before parking again.

Ссылка: [tokio_metrics::RuntimeMetrics::total_noop_count]

max_noop_count: u64

The maximum number of times any worker thread unparked but performed no work before parking again.

Ссылка: [tokio_metrics::RuntimeMetrics::max_noop_count]

min_noop_count: u64

The minimum number of times any worker thread unparked but performed no work before parking again.

Ссылка: [tokio_metrics::RuntimeMetrics::min_noop_count]

total_steal_count: u64

The number of tasks worker threads stole from another worker thread.

Ссылка: [tokio_metrics::RuntimeMetrics::total_steal_count]

max_steal_count: u64

The maximum number of tasks any worker thread stole from another worker thread.

Ссылка: [tokio_metrics::RuntimeMetrics::max_steal_count]

min_steal_count: u64

The minimum number of tasks any worker thread stole from another worker thread.

Ссылка: [tokio_metrics::RuntimeMetrics::min_steal_count]

total_steal_operations: u64

The number of times worker threads stole tasks from another worker thread.

Ссылка: [tokio_metrics::RuntimeMetrics::total_steal_operations]

max_steal_operations: u64

The maximum number of times any worker thread stole tasks from another worker thread.

Ссылка: [tokio_metrics::RuntimeMetrics::max_steal_operations]

min_steal_operations: u64

The minimum number of times any worker thread stole tasks from another worker thread.

Ссылка: [tokio_metrics::RuntimeMetrics::min_steal_operations]

num_remote_schedules: u64

The number of tasks scheduled from outside of the runtime.

Ссылка: [tokio_metrics::RuntimeMetrics::num_remote_schedules]

total_local_schedule_count: u64

The number of tasks scheduled from worker threads.

Ссылка: [tokio_metrics::RuntimeMetrics::total_local_schedule_count]

max_local_schedule_count: u64

The maximum number of tasks scheduled from any one worker thread.

Ссылка: [tokio_metrics::RuntimeMetrics::max_local_schedule_count]

min_local_schedule_count: u64

The minimum number of tasks scheduled from any one worker thread.

Ссылка: [tokio_metrics::RuntimeMetrics::min_local_schedule_count]

total_overflow_count: u64

The number of times worker threads saturated their local queues.

Ссылка: [tokio_metrics::RuntimeMetrics::total_overflow_count]

max_overflow_count: u64

The maximum number of times any one worker saturated its local queue.

Ссылка: [tokio_metrics::RuntimeMetrics::max_overflow_count]

min_overflow_count: u64

The minimum number of times any one worker saturated its local queue.

Ссылка: [tokio_metrics::RuntimeMetrics::min_overflow_count]

total_polls_count: u64

The number of tasks that have been polled across all worker threads.

Ссылка: [tokio_metrics::RuntimeMetrics::total_polls_count]

max_polls_count: u64

The maximum number of tasks that have been polled in any worker thread.

Ссылка: [tokio_metrics::RuntimeMetrics::max_polls_count]

min_polls_count: u64

The minimum number of tasks that have been polled in any worker thread.

Ссылка: [tokio_metrics::RuntimeMetrics::min_polls_count]

total_local_queue_depth: usize

The total number of tasks currently scheduled in workers’ local queues.

Ссылка: [tokio_metrics::RuntimeMetrics::total_local_queue_depth]

max_local_queue_depth: usize

The maximum number of tasks currently scheduled any worker’s local queue.

Ссылка: [tokio_metrics::RuntimeMetrics::max_local_queue_depth]

min_local_queue_depth: usize

The minimum number of tasks currently scheduled any worker’s local queue.

Ссылка: [tokio_metrics::RuntimeMetrics::min_local_queue_depth]

blocking_queue_depth: usize

The number of tasks currently waiting to be executed in the runtime’s blocking threadpool.

Ссылка: [tokio_metrics::RuntimeMetrics::blocking_queue_depth]

live_tasks_count: usize

The current number of alive tasks in the runtime.

Ссылка: [tokio_metrics::RuntimeMetrics::live_tasks_count]

blocking_threads_count: usize

The number of additional threads spawned by the runtime.

Ссылка: [tokio_metrics::RuntimeMetrics::blocking_threads_count]

idle_blocking_threads_count: usize

The number of idle threads, which have spawned by the runtime for spawn_blocking calls.

Ссылка: [tokio_metrics::RuntimeMetrics::idle_blocking_threads_count]

budget_forced_yield_count: u64

Returns the number of times that tasks have been forced to yield back to the scheduler after exhausting their task budgets.

Ссылка: [tokio_metrics::RuntimeMetrics::budget_forced_yield_count]

io_driver_ready_count: u64

Returns the number of ready events processed by the runtime’s I/O driver.

Ссылка: [tokio_metrics::RuntimeMetrics::io_driver_ready_count]

mean_polls_per_park: f64

Returns the ratio of the total_polls_count to the total_noop_count.

busy_ratio: f64

Returns the ratio of the total_busy_duration to the elapsed.